==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/SciFigs/src/XYColorLinesProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef XYCOLORLINESPROPERTIES_H
#define XYCOLORLINESPROPERTIES_H

#include <QGpGuiTools.h>

#include "ui_XYColorLinesProperties.h"

namespace SciFigs {

class XYColorLines;
class XUniqueYColorLines;

class XYColorLinesProperties : public PropertyWidget, private Ui::XYColorLinesProperties
{
public:
  XYColorLinesProperties(QWidget * parent=nullptr);

  enum Properties{LineWeight, SignChangeThreshold};
};

} // namespace SciFigs

#endif // XYCOLORLINESPROPERTIES_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/SciFigs/src/XYColorLinesProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef XYCOLORLINESPROPERTIES_H
#define XYCOLORLINESPROPERTIES_H

#include <QGpGuiTools.h>

#include "ui_XYColorLinesProperties.h"
#include "SciFigsDLLExport.h"

namespace SciFigs {

  class SCIFIGS_EXPORT XYColorLinesProperties : public PropertyWidget, private Ui::XYColorLinesProperties
  {
  public:
    XYColorLinesProperties(QWidget * parent=nullptr);

    enum Properties{LineWeight, SignChangeThreshold};
  };

} // namespace SciFigs

#endif // XYCOLORLINESPROPERTIES_H
